@@ -1,3 +1,8 @@
+/*
+ * SPDX-FileCopyrightText: 2025 Univention GmbH
+ * SPDX-License-Identifier: AGPL-3.0-only
+ */
+
 #include "internal.h"
 /*! @file license.c
         @brief general lib license functions
@@ -19,6 +24,7 @@ int univention_license_init(void) {
 	is_init = 1;
 
 	/*init debug*/
+	univention_debug_set_structured(1);
 	univention_debug_init("stderr", UV_DEBUG_FLUSH, UV_DEBUG_NO_FUNCTION);
 	univention_debug_set_level(UV_DEBUG_LDAP, UV_DEBUG_ERROR);
 	univention_debug_set_level(UV_DEBUG_LICENSE, UV_DEBUG_ERROR);
